@@ -1,18 +1,43 @@
+//  matchingR -- Matching Algorithms in R and C++
+//
+//  Copyright (C) 2015  Jan Tilly <jtilly@econ.upenn.edu>
+//                      Nick Janetos <njanetos@econ.upenn.edu>
+//
+//  This file is part of matchingR.
+//
+//  matchingR is free software: you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation, either version 2 of the License, or
+//  (at your option) any later version.
+//
+//  matchingR is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU General Public License for more details.
+
 #include "roommate.h"
 
 // [[Rcpp::depends(RcppArmadillo)]]
 
 //' Computes a stable roommate matching
 //'
-//' This function computes the Irving (1985) algorithm for finding
-//' a stable matching in a one-sided matching market. Note that neither
-//' existence nor uniqueness is guaranteed, this algorithm finds one
-//' matching, not all of them. If no matching exists, returns 0.
-//'
-//' @param pref A matrix with agent's cardinal preferences. Column i is agent i's preferences.
-//' @return A list with the matchings made. Unmatched agents are 'matched' to N.
+//' This is the C++ wrapper for the stable roommate problem. Users should not
+//' call this function directly, but instead use
+//' \code{\link{roommate}}.
+//' 
+//' @param pref is a matrix with the preference order of each individual in the
+//'   market. If there are \code{n} individuals, then this matrix will be of
+//'   dimension \code{n-1} by \code{n}. The \code{i,j}th element refers to
+//'   \code{j}'s \code{i}th most favorite partner. Preference orders must be
+//'   specified using C++ indexing (starting at 0). The matrix \code{pref} must
+//'   be of dimension \code{n-1} by \code{n}.
+//' @return A vector of length \code{n} corresponding to the matchings that were
+//'   formed (using C++ indexing). E.g. if the \code{4}th element of this vector
+//'   is \code{0} then individual \code{4} was matched with individual \code{1}.
+//'   If no stable matching exists, then this function returns a vector of
+//'   zeros.
 // [[Rcpp::export]]
-List stableRoommateMatching(const umat pref) {
+uvec cpp_wrapper_irving(const umat pref) {
 
     // Number of participants
     uword N = pref.n_cols;
@@ -37,7 +62,7 @@ List stableRoommateMatching(const umat pref) {
         stable = true;
         for (uword n = 0; n < N; n++) {
             // n proposes to the next best guy if he hasn't proposed to everyone already...
-            if (proposed_to(n) >= N-1) { return List::create(_["matchings"] = 0); }
+            if (proposed_to(n) >= N-1) { return matchings.zeros(); }
 
             // or if he has no proposals accepted by anyone.
             if (proposal_to(n) == N) {
@@ -46,9 +71,8 @@ List stableRoommateMatching(const umat pref) {
                 uword proposee = pref(proposed_to(n), n);
 
                 // proposee's preferences
-                //const uword * prop_call = pref.colptr(proposee);
                 const uvec prop_call = pref.col(proposee);
-                
+
                 // find proposee's opinion of the proposer (lower is better)
                 uword op = N;
                 for (uword i = 0; i < prop_call.n_elem; i++) {
@@ -57,11 +81,9 @@ List stableRoommateMatching(const umat pref) {
                         break;
                     }
                 }
-                
-                if (op == N) {
-                    stop("Invalid preference matrix: Incomplete preferences.");
-                }
-                
+
+                if (op == N) { stop("Invalid preference matrix: Incomplete preferences."); }
+
                 // find proposee's opinion of his current match
                 // lower is better
                 // unmmatched is N
@@ -72,7 +94,7 @@ List stableRoommateMatching(const umat pref) {
                         break;
                     }
                 }
-                
+
                 // if the next best guy likes him he accepts
                 if (op < op_curr) {
 
@@ -113,7 +135,7 @@ List stableRoommateMatching(const umat pref) {
             if (table[n][i] == proposal_from(n)) {
                 break;
             } else {
-                if (table[n].size() == 0) { return List::create(_["matchings"] = 0); }
+                if (table[n].size() == 0) { return matchings.zeros(); }
                 // find and erase from the table
                 bool erased = false;
                 for (uword j = 0; j < table[table[n].back()].size(); j++) {
@@ -123,7 +145,7 @@ List stableRoommateMatching(const umat pref) {
                         break;
                     }
                 }
-                if (!erased) { return List::create(_["matchings"]   = 0); }
+                if (!erased) { return matchings.zeros(); }
                 table[n].pop_back();
             }
         }
@@ -162,15 +184,27 @@ List stableRoommateMatching(const umat pref) {
                 for (uword i = rot_tail + 1; i < index.size(); i++) {
                     while(table[x[i]].back() != index[i-1]) {
                         // find and erase from the table
-                        bool erased = false;
-                        for (uword j = 0; j < table[table[x[i]].back()].size(); j++) {
-                            if (table[table[x[i]].back()][j] == x[i]) {
-                                table[table[x[i]].back()].erase(table[table[x[i]].back()].begin() + j);
-                                erased = true;
-                                break;
-                            }
-                        }
-                        if (!erased) { return List::create(_["matchings"]   = 0); }
+                        // x[i] needs to be removed from  table[table[x[i]].back()], and
+                        // table[table[x[i]].back()][x[i]] needs to be removed from
+                        // table[x[i]].
+                        uword tab_size = table[table[x[i]].back()].size();
+
+                        // Remove x[i] from table[table[x[i]].back()]
+                        // If x[i] is not in table[table[x[i]].back()], then it should remove
+                        // nothing.
+                        // This uses an 'erase-remove' idiom from the std library.
+                        table[table[x[i]].back()].erase(std::remove(table[table[x[i]].back()].begin(),
+                                                        table[table[x[i]].back()].end(),
+                                                        x[i]),
+                                                        table[table[x[i]].back()].end());
+
+                        // Check to see if it removed x[i] or not (whether the table's the same size)
+                        if (tab_size == table[table[x[i]].back()].size()) { return matchings.zeros(); }
+
+                        // Check to see if there's only one element remaining (if so, no stable matching.)
+                        if (table[x[i]].size() == 1) { return matchings.zeros(); }
+
+                        // Remove table[table[x[i]].back()][x[i]] from table[x[i]] (it should be at the end).
                         table[x[i]].pop_back();
                     }
                 }
@@ -180,9 +214,7 @@ List stableRoommateMatching(const umat pref) {
 
     // Check if anything is empty
     for (uword i = 0; i < table.size(); i++) {
-        if (table[i].empty()) {
-            return List::create(_["matchings"] = 0);
-        }
+        if (table[i].empty()) { return matchings.zeros(); }
     }
 
     // Create the matchings
@@ -191,7 +223,7 @@ List stableRoommateMatching(const umat pref) {
         matchings[n] = table[n][0];
     }
 
-    return List::create(_["matchings"] = matchings);
+    return matchings;
 }
 
 //' Check if a matching solves the stable roommate problem
@@ -200,14 +232,20 @@ List stableRoommateMatching(const umat pref) {
 //' preferences. This function checks if there's an unmatched pair that would
 //' rather be matched with each other than with their assigned partners.
 //'
-//' @param pref is a matrix with ordinal rankings of the participants
-//' @param matchings is an nx1 matrix encoding who is matched to whom using
-//' R style indexing
+//' @param pref is a matrix with the preference order of each individual in the
+//'   market. If there are \code{n} individuals, then this matrix will be of
+//'   dimension \code{n-1} by \code{n}. The \code{i,j}th element refers to
+//'   \code{j}'s \code{i}th most favorite partner. Preference orders must be
+//'   specified using C++ indexing (starting at 0). The matrix \code{pref} must
+//'   be of dimension \code{n-1} by \code{n}.
+//' @param matchings is a vector of length \code{n} corresponding to the
+//'   matchings that were formed (using C++ indexing). E.g. if the \code{4}th
+//'   element of this vector is \code{0} then individual \code{4} was matched
+//'   with individual \code{1}. If no stable matching exists, then this function
+//'   returns a vector of zeros.
 //' @return true if the matching is stable, false otherwise
 // [[Rcpp::export]]
-bool checkStabilityRoommate(umat& pref, umat& matchings) {
-
-    matchings = matchings - 1;
+bool cpp_wrapper_irving_check_stability(umat& pref, umat& matchings) {
 
     // loop through everyone and check whether there's anyone else
     // who they'd rather be with
@@ -231,9 +269,7 @@ bool checkStabilityRoommate(umat& pref, umat& matchings) {
             }
 
             // do they both want to switch?
-            if (i_prefers && j_prefers) {
-                return false;
-            }
+            if (i_prefers && j_prefers) { return false; }
         }
     }
 
